@@ -1,4 +1,4 @@
-#$Id: FormValidator.pm,v 1.10 2003/08/04 03:01:56 alex Exp $
+#$Id: FormValidator.pm,v 1.11 2003/08/04 03:01:56 alex Exp $
 
 package HTML::Template::Associate::FormValidator;
 use strict;
@@ -7,7 +7,7 @@ BEGIN {
 	use Exporter ();
         require HTML::Template::Associate;
 	use vars qw ($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
-	$VERSION     = qw ( $Revision: 1.10 $ )[1];
+	$VERSION     = qw ( $Revision: 1.11 $ )[1];
 	@ISA         = qw ( HTML::Template::Associate Exporter);
 	#Give a hoot don't pollute, do not export more than needed by default
 	@EXPORT      = qw ();
@@ -187,7 +187,7 @@ sub param {
              $value ) = @_;
         $self->{&FIELD_HASH}->{$field} = $value if $value;
 	return keys %{ $self->{&FIELD_HASH} } unless $field;
-        log ( sprintf ( ERROR_MISSING_FIELD, $field ) ) unless exists $self->{&FIELD_HASH}->{$field};
+        $self->SUPER::log ( sprintf ( ERROR_MISSING_FIELD, $field ) ) unless exists $self->{&FIELD_HASH}->{$field};
 	return $self->{&FIELD_HASH}->{$field};
 }
 
@@ -211,6 +211,8 @@ sub runloop {
 	for my $field ( @fields ) {
 		my $field_value = ref $results->$method eq q{ARRAY} ? 
 			$results->$method ( $field ) : $results->$method->{$field};
+		$field_value = ref $field_value eq q{ARRAY} ? 
+			join q{,}, @$field_value : $field_value;
         	$self->param ( $field_prefix . $field, $field_value );
 		my $loop_name = $field_prefix . TMPL_POSTFIX_LOOP;
 		push @{ $self->{&FIELD_HASH}->{$loop_name} }, { 
